"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initProjectCommand = void 0;
const aws_schema_1 = require("@takomo/aws-schema");
const core_1 = require("@takomo/core");
const util_1 = require("@takomo/util");
const joi_1 = __importDefault(require("joi"));
const initProject = async (ctx, io, input, configRepository) => {
    const { timer } = input;
    const info = await io.promptProjectInformation(ctx, input);
    const description = await configRepository.putProjectConfig(info);
    timer.stop();
    return {
        description,
        message: "Success",
        status: "SUCCESS",
        success: true,
        timer,
    };
};
const inputSchema = (ctx) => {
    const { region } = aws_schema_1.createAwsSchemas({ regions: ctx.regions });
    const { project } = core_1.createCommonSchema();
    return joi_1.default.object({
        project,
        regions: joi_1.default.array().items(region).unique(),
        createSamples: joi_1.default.boolean(),
    }).unknown(true);
};
const initProjectCommand = async ({ ctx, io, input, configRepository }) => util_1.validateInput(inputSchema(ctx), input)
    .then((input) => initProject(ctx, io, input, configRepository))
    .then(io.printOutput);
exports.initProjectCommand = initProjectCommand;
//# sourceMappingURL=command.js.map